@@ -1063,7 +1063,8 @@ def load_options():
     except:
         name_list = []
     return name_list
-    
+
+from scpantheon.extension.Check_Histogram import module
     
 def load_module(active):
     global path_
@@ -1089,18 +1090,13 @@ def load_module(active):
             try:
                 new_class = module_name.new_layout()
             except:            
-                mod = importlib.import_module(module_name)
+                mod = importlib.import_module(module_name) # usual way
                 new_class = mod.new_layout()
             clear = Button(label='Clear the figures!', button_type='warning', name=str(ind))
             clear.on_click(lambda: clear_cb(clear.name))
             new_buttons = column(new_class.add(), clear)
             # append extended buttons
             buttons_g = find_buttons(new_buttons, buttons_g)
-            '''
-            print('after append=====')
-            for i in range(buttons_n, len(buttons_g)):
-                print(buttons_g[i])
-            '''
             plot.tweak_buttons_group(buttons_g)
             if but != None and but.visible == False:
                 but.visible = True # already created model
